#
# spec file for package ffmpeg-2
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Create proper conflicts to make sure we require all from one version
# p:   Conflict string, eg if you need them all for requires instead
#      Default value Conflicts:
# c:   copmare string ie "<" or ">=", must be defined
# v:   version string ie. "< 42.3.4" or ">= 15.0.2.1", must be defined
%define devel_conflicts(p:c:v:) \
%define preamble_string %{-p:%{-p*}}%{!-p:Conflicts:} \
%define comparator %{-c:%{-c*}}%{!-c:%{error:Comparator not defined}} \
%define conflicts_version %{-v:%{-v*}}%{!-v:%{error:Version not defined}} \
\
%{preamble_string} libavcodec-devel %{comparator} %{conflicts_version} \
%{preamble_string} libavdevice-devel %{comparator} %{conflicts_version} \
%{preamble_string} libavfilter-devel %{comparator} %{conflicts_version} \
%{preamble_string} libavformat-devel %{comparator} %{conflicts_version} \
%{preamble_string} libavresample-devel %{comparator} %{conflicts_version} \
%{preamble_string} libavutil-devel %{comparator} %{conflicts_version} \
%{preamble_string} libpostproc-devel %{comparator} %{conflicts_version} \
%{preamble_string} libswresample-devel %{comparator} %{conflicts_version} \
%{preamble_string} libswscale-devel %{comparator} %{conflicts_version} \
%{preamble_string} ffmpeg-private-devel %{comparator} %{conflicts_version} \
%{nil}

%bcond_with    fdk_aac
%bcond_with    librtmp
%bcond_with    vo_aacenc
%bcond_with    x264
%bcond_with    x265
%bcond_with    xvid
%bcond_with    opencore

# Full build or just support package on older codestream
%bcond_with full_build

%define _name ffmpeg
%define _major_version 2
%define _major_expected 3
Name:           ffmpeg-2
Version:        2.8.15
Release:        12.17
Summary:        Library for working with various multimedia formats
License:        LGPL-2.1-or-later AND GPL-2.0-or-later
Group:          Productivity/Multimedia/Video/Editors and Convertors
Url:            https://ffmpeg.org/

#Freshcode-URL:    http://freshcode.club/projects/ffmpeg
#Git-Clone:     git://source.ffmpeg.org/ffmpeg
Source:         https://www.ffmpeg.org/releases/%_name-%version.tar.xz
Source2:        https://www.ffmpeg.org/releases/%_name-%version.tar.xz.asc
Source3:        ffmpeg2-rpmlintrc
Source4:        enable_decoders
Source5:        enable_encoders
Source6:        enable_demuxers
Source7:        enable_muxers
Source99:       baselibs.conf
Patch1:         ffmpeg-libcdio_cdda-pkgconfig.patch
Patch2:         ffmpeg-2.4.5-arm6l.patch
Patch3:         ffmpeg-pkgconfig-version.patch
Patch4:         ffmpeg-new-coder-errors.diff
Patch5:         ffmpeg-codec-choice.diff
BuildRequires:  ladspa-devel
BuildRequires:  libgsm-devel
BuildRequires:  libmp3lame-devel
BuildRequires:  pkg-config
BuildRequires:  yasm
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(celt) >= 0.11.0
BuildRequires:  pkgconfig(enca)
BuildRequires:  pkgconfig(fontconfig) >= 2.4.2
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(fribidi) >= 0.19.0
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libass)
BuildRequires:  pkgconfig(libbluray)
BuildRequires:  pkgconfig(libcdio)
BuildRequires:  pkgconfig(libcdio_paranoia)
BuildRequires:  pkgconfig(libdc1394-2)
BuildRequires:  pkgconfig(liboil-0.3) >= 0.3.15
BuildRequires:  pkgconfig(libopenjpeg)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libraw1394)
BuildRequires:  pkgconfig(libva) >= 0.35.0
BuildRequires:  pkgconfig(libwebp) >= 0.4
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(schroedinger-1.0)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(speex)
BuildRequires:  pkgconfig(theora) >= 1.1
BuildRequires:  pkgconfig(twolame)
BuildRequires:  pkgconfig(vdpau)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(vpx) >= 1.3.0
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-render)
BuildRequires:  pkgconfig(xcb-shape)
BuildRequires:  pkgconfig(xcb-shm)
BuildRequires:  pkgconfig(xcb-xfixes)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(zlib)
%if 0%{?BUILD_ORIG}
%if %{with fdk_aac}
BuildRequires:  pkgconfig(fdk-aac)
%endif
%if %{with librtmp}
BuildRequires:  pkgconfig(librtmp)
%endif
%if %{with xvid}
BuildRequires:  libxvidcore-devel
%endif
%if %{with opencore}
BuildRequires:  pkgconfig(opencore-amrnb)
%endif
%if %{with x264}
BuildRequires:  pkgconfig(x264)
%endif
%if %{with x265}
BuildRequires:  pkgconfig(x265)
%endif
%endif
Provides:       ffmpeg-tools = %{version}
Obsoletes:      ffmpeg-tools < %{version}
Provides:       ffmpeg = %version
Obsoletes:      ffmpeg < %version
Requires:       libavcodec56 = %version-%release
Requires:       libavdevice56 = %version-%release
Requires:       libavfilter5 = %version-%release
Requires:       libavformat56 = %version-%release
Requires:       libavresample2 = %version-%release
Requires:       libavutil54 = %version-%release
Requires:       libpostproc53 = %version-%release
Requires:       libswresample1 = %version-%release
Requires:       libswscale3 = %version-%release

%description
FFmpeg is a multimedia framework, able to decode, encode,
transcode, mux, demux, stream, filter and play several formats
that humans and machines have created.
%if !0%{?BUILD_ORIG}

This build of ffmpeg is limited in the number of codecs supported.
%endif

%package -n libavcodec56
Summary:        FFmpeg codec library
Group:          System/Libraries
Requires:       libavutil54 = %version-%release
Requires:       libswresample1 = %version-%release
Provides:       libavcodec = %version-%release
%if 0%{?BUILD_ORIG}
Provides:       libavcodec-full = %version-%release
# This can be required by packages likes vlc-codecs - following the shlib name to not get random lib providers
Provides:       libavcodec56(unrestricted)
%endif

%description -n libavcodec56
The libavcodec library provides a generic encoding/decoding framework
and contains multiple decoders and encoders for audio, video and
subtitle streams, and several bitstream filters.
%if !0%{?BUILD_ORIG}

This build of ffmpeg is limited in the number of codecs supported.
%endif

%package libavcodec-devel
Summary:        Development files for FFmpeg's codec library
Group:          Development/Libraries/C and C++
Provides:       libavcodec-devel = %version-%release
Obsoletes:      libavcodec-devel < %version-%release
Requires:       %{name}-libavresample-devel = %version-%release
Requires:       %{name}-libavutil-devel = %version-%release
Requires:       libavcodec56 = %version-%release
%devel_conflicts -c < -v %{_major_version}
%devel_conflicts -c >= -v %{_major_expected}

%description libavcodec-devel
The libavcodec library provides a generic encoding/decoding framework
and contains multiple decoders and encoders for audio, video and
subtitle streams, and several bitstream filters.

This subpackage contains the headers for FFmpeg libavcodec.

%package -n libavdevice56
Summary:        FFmpeg device library
Group:          System/Libraries
Requires:       libavcodec56 = %version-%release
Requires:       libavfilter5 = %version-%release
Requires:       libavformat56 = %version-%release
Requires:       libavutil54 = %version-%release

%description -n libavdevice56
The libavdevice library provides a generic framework for grabbing from
and rendering to many common multimedia input/output devices, and
supports several input and output devices, including Video4Linux2, VfW,
DShow, and ALSA.

%package libavdevice-devel
Summary:        Development files for FFmpeg's device library
Group:          Development/Libraries/C and C++
Provides:       ffmpeg-devel = %version-%release
Conflicts:      ffmpeg-devel
Provides:       ffmpeg2-devel = %version-%release
Obsoletes:      ffmpeg2-devel < %version-%release
Provides:       libavdevice-devel = %version-%release
Obsoletes:      libavdevice-devel < %version-%release
Requires:       %{name}-libavcodec-devel = %version-%release
Requires:       %{name}-libavfilter-devel = %version-%release
Requires:       %{name}-libavformat-devel = %version-%release
Requires:       %{name}-libavresample-devel = %version-%release
Requires:       %{name}-libavutil-devel = %version-%release
Requires:       %{name}-libpostproc-devel = %version-%release
Requires:       %{name}-libswresample-devel = %version-%release
Requires:       %{name}-libswscale-devel = %version-%release
Requires:       libavdevice56 = %version-%release
%devel_conflicts -c < -v %{_major_version}
%devel_conflicts -c >= -v %{_major_expected}

%description libavdevice-devel
The libavdevice library provides a generic framework for grabbing from
and rendering to many common multimedia input/output devices, and
supports several input and output devices, including Video4Linux2, VfW,
DShow, and ALSA.

This subpackage contains the headers for FFmpeg libavdevice.

%package -n libavfilter5
Summary:        FFmpeg audio and video filtering library
Group:          System/Libraries
Requires:       libavcodec56 = %version-%release
Requires:       libavformat56 = %version-%release
Requires:       libavresample2 = %version-%release
Requires:       libavutil54 = %version-%release
Requires:       libpostproc53 = %version-%release
Requires:       libswresample1 = %version-%release
Requires:       libswscale3 = %version-%release

%description -n libavfilter5
The libavfilter library provides a generic audio/video filtering
framework containing several filters, sources and sinks.

%package libavfilter-devel
Summary:        Development files for FFmpeg's audio/video filter library
Group:          Development/Libraries/C and C++
Provides:       libavfilter-devel = %version-%release
Obsoletes:      libavfilter-devel < %version-%release
Requires:       %{name}-libavcodec-devel = %version-%release
Requires:       %{name}-libavformat-devel = %version-%release
Requires:       %{name}-libavresample-devel = %version-%release
Requires:       %{name}-libavutil-devel = %version-%release
Requires:       %{name}-libpostproc-devel = %version-%release
Requires:       %{name}-libswresample-devel = %version-%release
Requires:       %{name}-libswscale-devel = %version-%release
Requires:       libavfilter5 = %version-%release
%devel_conflicts -c < -v %{_major_version}
%devel_conflicts -c >= -v %{_major_expected}

%description libavfilter-devel
The libavfilter library provides a generic audio/video filtering
framework containing several filters, sources and sinks.

This subpackage contains the headers for FFmpeg libavfilter.

%package -n libavformat56
Summary:        FFmpeg's stream format library
Group:          System/Libraries
Requires:       libavcodec56 = %version-%release
Requires:       libavutil54 = %version-%release

%description -n libavformat56
The libavformat library provides a generic framework for multiplexing
and demultiplexing (muxing and demuxing) audio, video and subtitle
streams. It encompasses multiple muxers and demuxers for multimedia
container formats.
%if !0%{?BUILD_ORIG}

This build of ffmpeg is limited in the number of codecs supported.
%endif

%package libavformat-devel
Summary:        Development files for FFmpeg's stream format library
Group:          Development/Libraries/C and C++
Provides:       libavformat-devel = %version-%release
Obsoletes:      libavformat-devel < %version-%release
Requires:       %{name}-libavcodec-devel = %version-%release
Requires:       %{name}-libswresample-devel = %version-%release
Requires:       libavformat56 = %version-%release
Requires:       libavutil-devel = %version-%release
%devel_conflicts -c < -v %{_major_version}
%devel_conflicts -c >= -v %{_major_expected}

%description libavformat-devel
The libavformat library provides a generic framework for multiplexing
and demultiplexing (muxing and demuxing) audio, video and subtitle
streams. It encompasses multiple muxers and demuxers for multimedia
container formats.

This subpackage contains the headers for FFmpeg libavformat.

%package -n libavresample2
Summary:        FFmpeg alternate audio resampling library
Group:          System/Libraries
Requires:       libavutil54 = %version-%release

%description -n libavresample2
An audio resampling library that is being provided for drop-in
compatibility with libav.

It is advised to use libswresample for new code.

%package libavresample-devel
Summary:        Development files for libavresample as present in FFmpeg
Group:          Development/Libraries/C and C++
Provides:       libavresample-devel = %version-%release
Obsoletes:      libavresample-devel < %version-%release
Requires:       %{name}-libavutil-devel = %version-%release
Requires:       libavresample2 = %version-%release
%devel_conflicts -c < -v %{_major_version}
%devel_conflicts -c >= -v %{_major_expected}

%description libavresample-devel
An audio resampling library that is being provided for drop-in
compatibility with libav.

It is advised to use libswresample for new code.

This subpackage contains the headers for FFmpeg's copy of libavresample.

%package -n libavutil54
Summary:        FFmpeg's utility library
Group:          System/Libraries

%description -n libavutil54
The libavutil library is a utility library to aid portable multimedia
programming. It contains safe portable string functions, random
number generators, data structures, additional mathematics functions,
cryptography and multimedia related functionality (like enumerations
for pixel and sample formats).

%package libavutil-devel
Summary:        Development files for FFmpeg's utility library
Group:          Development/Libraries/C and C++
Provides:       libavutil-devel = %version-%release
Obsoletes:      libavutil-devel < %version-%release
Requires:       libavutil54 = %version-%release
%devel_conflicts -c < -v %{_major_version}
%devel_conflicts -c >= -v %{_major_expected}

%description libavutil-devel
The libavutil library is a utility library to aid portable multimedia
programming. It contains safe portable string functions, random
number generators, data structures, additional mathematics functions,
cryptography and multimedia related functionality (like enumerations
for pixel and sample formats).

This subpackage contains the headers for FFmpeg libavutil.

%package -n libpostproc53
Summary:        FFmpeg post-processing library
Group:          System/Libraries
Requires:       libavutil54 = %version-%release

%description -n libpostproc53
A library with video postprocessing filters, such as deblocking and
deringing filters, noise reduction, automatic contrast and brightness
correction, linear/cubic interpolating deinterlacing.

%package libpostproc-devel
Summary:        Development files for the FFmpeg post-processing library
Group:          Development/Libraries/C and C++
Provides:       libpostproc-devel = %version-%release
Obsoletes:      libpostproc-devel < %version-%release
Requires:       %{name}-libavutil-devel = %version-%release
Requires:       libpostproc53 = %version
%devel_conflicts -c < -v %{_major_version}
%devel_conflicts -c >= -v %{_major_expected}

%description libpostproc-devel
A library with video postprocessing filters, such as deblocking and
deringing filters, noise reduction, automatic contrast and brightness
correction, linear/cubic interpolating deinterlacing.

This subpackage contains the headers for FFmpeg libpostproc.

%package -n libswresample1
Summary:        FFmpeg software resampling library
Group:          System/Libraries
Requires:       libavutil54 = %version-%release

%description -n libswresample1
The libswresample library performs audio conversion between different
sample rates, channel layout and channel formats.

%package libswresample-devel
Summary:        Development files for the FFmpeg software resampling library
Group:          Development/Libraries/C and C++
Provides:       libswresample-devel = %version-%release
Obsoletes:      libswresample-devel < %version-%release
Requires:       %{name}-libavutil-devel = %version-%release
Requires:       libswresample1 = %version-%release
%devel_conflicts -c < -v %{_major_version}
%devel_conflicts -c >= -v %{_major_expected}

%description libswresample-devel
The libswresample library performs audio conversion between different
sample rates, channel layout and channel formats.

This subpackage contains the headers for FFmpeg libswresample.

%package -n libswscale3
Summary:        FFmpeg image scaling and colorspace/pixel conversion library
Group:          System/Libraries
Requires:       libavutil54 = %version-%release

%description -n libswscale3
The libswscale library performs image scaling and colorspace and
pixel format conversion operations.

%package libswscale-devel
Summary:        Development files for FFmpeg's image scaling and colorspace library
Group:          Development/Libraries/C and C++
Provides:       libswscale-devel = %version-%release
Conflicts:      libswscale-devel
Requires:       %{name}-libavutil-devel = %version-%release
Requires:       libswscale3 = %version-%release
%devel_conflicts -c < -v %{_major_version}
%devel_conflicts -c >= -v %{_major_expected}

%description libswscale-devel
The libswscale library performs image scaling and colorspace and
pixel format conversion operations.

This subpackage contains the headers for FFmpeg libswscale.


%prep
%setup -qn %_name-%version
%autopatch -p1

%build
perl -i -pe 's{__TIME__|__DATE__}{"$&"}g' *.c

CFLAGS="%optflags" \
./configure \
	--prefix="%_prefix" --libdir="%_libdir" --shlibdir="%_libdir" \
	--incdir="%_includedir/ffmpeg" \
	--extra-cflags="%optflags" --optflags="%optflags" \
	--disable-htmlpages \
	--enable-pic --disable-stripping \
	--enable-shared --disable-static \
	--enable-runtime-cpudetect \
	--enable-gpl \
	--disable-openssl \
	--enable-avresample \
	--enable-libcdio \
	--enable-gnutls \
	--enable-ladspa \
	--enable-libass \
	--enable-libbluray \
	--enable-libcelt \
	--enable-libcdio \
	--enable-libdc1394 \
	--enable-libfreetype \
	--enable-libgsm \
	--enable-libopenjpeg \
	--enable-libopus \
	--enable-libpulse \
	--enable-libschroedinger \
	--enable-libspeex \
	--enable-libtheora \
	--enable-libvorbis \
	--enable-libvpx \
	--enable-libwebp \
	--enable-pic \
	--enable-pthreads \
	--enable-vaapi \
	--enable-vdpau \
%if 0%{?BUILD_ORIG}
%if %{with fdk_aac}
	--enable-libfdk_aac --enable-nonfree \
%endif
	--enable-libmp3lame \
%if %{with opencore}
	--enable-libopencore-amrnb \
	--enable-libopencore-amrwb \
	--enable-version3 \
%endif
	--enable-libtwolame \
%if %{with x264}
	--enable-libx264 \
%endif
%if %{with x265}
	--enable-libx265 \
%endif
%if %{with xvid}
	--enable-libxvid \
%endif
%else
	--disable-encoders \
	--disable-decoders \
	--disable-muxers \
	--disable-demuxers \
	--disable-decoder=mpeg1video,mpeg2video,mpeg4,h264,vc1 \
	--enable-encoder="$(perl -pe 's{^(\w*).*}{$1,}gs' <%_sourcedir/enable_encoders)" \
	--enable-decoder="$(perl -pe 's{^(\w*).*}{$1,}gs' <%_sourcedir/enable_decoders)" \
	--enable-muxer="$(perl -pe 's{^(\w*).*}{$1,}gs' <%_sourcedir/enable_muxers)" \
	--enable-demuxer="$(perl -pe 's{^(\w*).*}{$1,}gs' <%_sourcedir/enable_demuxers)" \
%endif
	--enable-x11grab
cat config.h
make %{?_smp_mflags} V=1

%global extratools aviocat cws2fws ffescape ffeval ffhash fourcc2pixfmt graph2dot ismindex pktdumper probetest qt-faststart seek_print trasher

for i in %extratools; do
	make "tools/$i"
done

%install
b="%buildroot"
%make_install install-man

%if %{with full_build}
rm -Rf "$b/%_datadir/ffmpeg/examples"
for i in %extratools; do
	cp -a "tools/$i" "$b/%_bindir/"
done
%else
rm -Rf "$b/%_bindir" "$b/%_mandir/man1/" "$b/%_datadir/ffmpeg"
%endif

%post   -n libavcodec56 -p /sbin/ldconfig
%postun -n libavcodec56 -p /sbin/ldconfig
%post   -n libavdevice56 -p /sbin/ldconfig
%postun -n libavdevice56 -p /sbin/ldconfig
%post   -n libavfilter5 -p /sbin/ldconfig
%postun -n libavfilter5 -p /sbin/ldconfig
%post   -n libavformat56 -p /sbin/ldconfig
%postun -n libavformat56 -p /sbin/ldconfig
%post   -n libavresample2 -p /sbin/ldconfig
%postun -n libavresample2 -p /sbin/ldconfig
%post   -n libavutil54 -p /sbin/ldconfig
%postun -n libavutil54 -p /sbin/ldconfig
%post   -n libpostproc53 -p /sbin/ldconfig
%postun -n libpostproc53 -p /sbin/ldconfig
%post   -n libswresample1 -p /sbin/ldconfig
%postun -n libswresample1 -p /sbin/ldconfig
%post   -n libswscale3 -p /sbin/ldconfig
%postun -n libswscale3 -p /sbin/ldconfig

%if %{with full_build}
%files
%doc Changelog CREDITS README.md
%_bindir/*
%_mandir/man1/ff*.1*
%_datadir/ffmpeg/
%endif

%files -n libavcodec56
%license COPYING.GPLv2 LICENSE.md
%_libdir/libavcodec.so.*

%files -n libavdevice56
%license COPYING.GPLv2 LICENSE.md
%_libdir/libavdevice.so.*

%files -n libavfilter5
%license COPYING.GPLv2 LICENSE.md
%_libdir/libavfilter.so.*

%files -n libavformat56
%license COPYING.GPLv2 LICENSE.md
%_libdir/libavformat.so.*

%files -n libavresample2
%license COPYING.GPLv2 LICENSE.md
%_libdir/libavresample.so.*

%files -n libavutil54
%license COPYING.GPLv2 LICENSE.md
%_libdir/libavutil.so.*

%files -n libpostproc53
%license COPYING.GPLv2 LICENSE.md
%_libdir/libpostproc.so.*

%files -n libswresample1
%license COPYING.GPLv2 LICENSE.md
%_libdir/libswresample.so.*

%files -n libswscale3
%license COPYING.GPLv2 LICENSE.md
%_libdir/libswscale.so.*

%files libavcodec-devel
%dir %_includedir/ffmpeg/
%_includedir/ffmpeg/libavcodec/
%_libdir/libavcodec.so
%_libdir/pkgconfig/libavcodec.pc
%_mandir/man3/libavcodec.3*

%files libavdevice-devel
%dir %_includedir/ffmpeg/
%_includedir/ffmpeg/libavdevice/
%_libdir/libavdevice.so
%_libdir/pkgconfig/libavdevice.pc
%_mandir/man3/libavdevice.3*

%files libavfilter-devel
%dir %_includedir/ffmpeg/
%_includedir/ffmpeg/libavfilter/
%_libdir/libavfilter.so
%_libdir/pkgconfig/libavfilter.pc
%_mandir/man3/libavfilter.3*

%files libavformat-devel
%dir %_includedir/ffmpeg/
%_includedir/ffmpeg/libavformat/
%_libdir/libavformat.so
%_libdir/pkgconfig/libavformat.pc
%_mandir/man3/libavformat.3*

%files libavresample-devel
%dir %_includedir/ffmpeg/
%_includedir/ffmpeg/libavresample/
%_libdir/libavresample.so
%_libdir/pkgconfig/libavresample.pc

%files libavutil-devel
%dir %_includedir/ffmpeg/
%_includedir/ffmpeg/libavutil/
%_libdir/libavutil.so
%_libdir/pkgconfig/libavutil.pc
%_mandir/man3/libavutil.3*

%files libpostproc-devel
%dir %_includedir/ffmpeg/
%_includedir/ffmpeg/libpostproc/
%_libdir/libpostproc.so
%_libdir/pkgconfig/libpostproc.pc

%files libswresample-devel
%dir %_includedir/ffmpeg/
%_includedir/ffmpeg/libswresample/
%_libdir/libswresample.so
%_libdir/pkgconfig/libswresample.pc
%_mandir/man3/libswresample.3*

%files libswscale-devel
%dir %_includedir/ffmpeg/
%_includedir/ffmpeg/libswscale/
%_libdir/libswscale.so
%_libdir/pkgconfig/libswscale.pc
%_mandir/man3/libswscale.3*

%changelog
* Tue Jul 31 2018 tchvatal@suse.com
- bsc#1103064 attempt to allow migration from the unprefixed devel
  packages cleanly
* Sun Jul 22 2018 tchvatal@suse.com
- Version update to 2.8.15:
  * avcodec/dvdsub_parser: Allocate input padding
  * avcodec/dvdsub_parser: Init output buf/size
  * avcodec/imgconvert: fix possible null pointer dereference
  * swresample/arm: rename labels to fix xcode build error
  * avformat/utils: fix mixed declarations and code
  * libwebpenc_animencoder: add missing braces to struct initialization
  * avformat/movenc: Check input sample count
  * avcodec/mjpegdec: Check for odd progressive RGB
  * avformat/movenc: Check that frame_types other than EAC3_FRAME_TYPE_INDEPENDENT have a supported substream id
  * avformat/mms: Add missing chunksize check
  * avformat/pva: Check for EOF before retrying in read_part_of_packet()
  * avcodec/indeo4: Check for end of bitstream in decode_mb_info()
  * avcodec/shorten: Fix undefined addition in shorten_decode_frame()
  * avcodec/jpeg2000dec: Fixes invalid shifts in jpeg2000_decode_packets_po_iteration()
  * avcodec/jpeg2000dec: Check that there are enough bytes for all tiles
  * avcodec/escape124: Fix spelling errors in comment
  * avcodec/ra144: Fix integer overflow in ff_eval_refl()
  * avcodec/cscd: Check output buffer size for lzo.
  * avcodec/escape124: Check buf_size against num_superblocks
  * avcodec/mjpegdec: Check for end of bitstream in ljpeg_decode_rgb_scan()
  * avcodec/aacdec_fixed: Fix undefined integer overflow in apply_independent_coupling_fixed()
  * avutil/common: Fix undefined behavior in av_clip_uintp2_c()
  * fftools/ffmpeg: Fallback to duration if sample rate is unavailable
  * avformat/mov: Only set pkt->duration to non negative values
  * avcodec/h264_mc_template: Only prefetch motion if the list is used.
  * avcodec/xwddec: Use ff_set_dimensions()
  * avcodec/wavpack: Fix overflow in adding tail
  * avcodec/shorten: Fix multiple integer overflows
  * avcodec/shorten: Sanity check nmeans
  * avcodec/mjpegdec: Fix integer overflow in ljpeg_decode_rgb_scan()
  * avcodec/truemotion2: Fix overflow in tm2_apply_deltas()
  * avcodec/opus_silk: Change silk_lsf2lpc() slightly toward silk/NLSF2A.c
  * avcodec/amrwbdec: Fix division by 0 in find_hb_gain()
  * avformat/mov: replace a value error by clipping into valid range in mov_read_stsc()
  * avformat/mov: Break out early if chunk_count is 0 in mov_build_index()
  * avcodec/fic: Avoid some magic numbers related to cursors
  * avcodec/g2meet: ask for sample with overflowing RGB
  * avcodec/aacdec_fixed: use 64bit to avoid overflow in rounding in apply_dependent_coupling_fixed()
  * avcodec/mpeg4videoenc: Use 64 bit for times in mpeg4_encode_gop_header()
  * avcodec/mlpdec: Only change noise_type if the related fields are valid
  * indeo4: Decode all or nothing of a band header.
  * avformat/mov: Only fail for STCO/STSC contradictions if both exist
  * avcodec/dirac_dwt: Fix integer overflow in COMPOSE_DD97iH0 / COMPOSE_DD137iL0
  * avcodec/fic: Check available input space for cursor
  * avcodec/g2meet: Check RGB upper limit
  * avcodec/jpeg2000dec: Fix undefined shift in the jpeg2000_decode_packets_po_iteration() CPRL case
  * avcodec/jpeg2000dec: Skip init for component in CPRL if nothing is to be done
  * avcodec/g2meet: Change order of operations to avoid undefined behavior
  * avcodec/flac_parser: Fix infinite loop
  * avcodec/wavpack: Fix integer overflow in DEC_MED() / INC_MED()
  * avcodec/error_resilience: Fix integer overflow in filter181()
  * avcodec/h263dec: Check slice_ret in mspeg4 slice loop
  * avcodec/elsdec: Fix memleaks
  * avcodec/vc1_block: simplify ac_val computation
  * avcodec/ffv1enc: Check that the crc + version combination is supported
  * lavf/http.c: Free allocated client URLContext in case of error.
  * avcodec/dsicinvideo: Fail if there is only a small fraction of the data available that comprises a full frame
  * avcodec/dsicinvideo: Propagate errors from cin_decode_rle()
  * avcodec/dfa: Check dimension against maximum
  * avcodec/cinepak: Skip empty frames
  * avcodec/cinepak: move some checks prior to frame allocation
  * swresample/arm: remove unintentional relocation.
  * doc/APIchanges: Fix typos in hashes
  * avformat/utils: Check cur_dts in update_initial_timestamps() more
  * avcodec/utils: Enforce minimum width also for VP5/6
  * avcodec/truemotion2: Propagate out of bounds error from GET_TOK()
  * avcodec/mjpegdec: Check input buffer size.
  * lavc/libopusdec: Allow avcodec_open2 to call .close
  * avcodec/movtextdec: Check style_start/end
  * avcodec/aacsbr_fixed: Fix integer overflow in sbr_hf_assemble()
  * swresample/swresample: Fix for seg fault in swr_convert_internal() -> sum2_float during dithering.
  * avcodec/aacdec_fixed: Fix integer overflow in apply_independent_coupling_fixed()
  * avcodec/cscd: Error out when LZ* decompression fails
  * avcodec/imgconvert: Fix loss mask bug in avcodec_find_best_pix_fmt_of_list()
  * avcodec/wmalosslessdec: Fix null pointer dereference in decode_frame()
  * avcodec/tableprint_vlc: Fix build failure with --enable-hardcoded-tables
  * avcodec/get_bits: Make sure the input bitstream with padding can be addressed
  * avformat/mov: Check STSC and remove invalid entries
  * avcodec/nuv: rtjpeg with dimensions less than 16 would result in no decoded pixels thus reject it
  * avcodec/nuv: Check for minimum input size for uncomprssed and rtjpeg
  * avcodec/wmalosslessdec: Reset num_saved_bits on error path
  * avformat/mov: Fix integer overflows related to sample_duration
  * avformat/oggparseogm: Check lb against psize
  * avformat/oggparseogm: Fix undefined shift in ogm_packet()
  * avformat/avidec: Fix integer overflow in cum_len check
  * avformat/oggparsetheora: Do not adjust AV_NOPTS_VALUE
  * avformat/utils: Fix integer overflow of fps_first/last_dts
  * libavformat/oggparsevorbis: Fix memleak on multiple headers
  * avcodec/bintext: sanity check dimensions
  * avcodec/utvideodec: Check subsample factors
  * avcodec/smc: Check input packet size
  * avcodec/cavsdec: Check alpha/beta offset
  * avcodec/diracdec: Fix integer overflow in mv computation
  * avcodec/jpeg2000dwt: Fix integer overflows in sr_1d53()
  * avcodec/diracdec: Use int64 in global mv to prevent overflow
  * avformat/hvcc: zero initialize the nal buffers past the last written byte
* Fri Jul  6 2018 tchvatal@suse.com
- Fix typo in swresample name
* Wed Jul  4 2018 tchvatal@suse.com
- Disable the full build as we are not primary package anywhere
* Wed Jul  4 2018 tchvatal@suse.com
- Fix copy&pasto in package name
* Tue Jul  3 2018 tchvatal@suse.com
- Add macros to allow conflicting with all other devel projects
  to ensure we always install only one specific ffmpeg
* Thu Jun 14 2018 tchvatal@suse.com
- Split back all the develpackages to match up ffmpeg3 and ffmpeg4
* Thu Jun 14 2018 tchvatal@suse.com
- Update to new bugfix release 2.8.14:
  * Various fixes around, merging the patches previously applied
  * See included Changelog for details
- Drop merged patches:
  * 0001-avcodec-exr-Check-tile-positions.patch
  * 0001-avformat-asfdec-Fix-DoS-in-asf_build_simple_index.patch
  * 0001-avformat-mov-Fix-DoS-in-read_tfra.patch
- Use %%autopatch
* Wed Jun 13 2018 tchvatal@suse.com
- Sync with ffmpeg-4
* Tue Sep 12 2017 jengelh@inai.de
- Add patches 0001-avformat-asfdec-Fix-DoS-in-asf_build_simple_index.patch
  [CVE-2017-14223] [boo#1058019],
  0001-avformat-mov-Fix-DoS-in-read_tfra.patch
  [CVE-2017-14222] [boo#1058020]
* Mon Sep  4 2017 jengelh@inai.de
- Update to new bugfix release 2.8.13
  * avformat/hls: Fix DoS due to infinite loop
    [CVE-2017-14058] [boo#1056762]
  * avformat/asfdec: Fix DoS due to lack of eof check
    [CVE-2017-14057] [boo#1056761]
  * avformat/cinedec: Fix DoS due to lack of eof check
    [CVE-2017-14059] [boo#1056763]
  * avformat/rl2: Fix DoS due to lack of eof check
    (code not enabled in openSUSE, though in packman)
    [CVE-2017-14056] [boo#1056760]
  * avformat/mvdec: Fix DoS due to lack of eof check
    [CVE-2017-14055] [boo#1056766]
  * avformat/mxfdec: Fix Sign error in mxf_read_primer_pack
    [CVE-2017-14169] [boo#1057536]
  * avformat/mxfdec: Fix DoS issues in mxf_read_index_entry_array
    [CVE-2017-14170] [boo#1057537]
  * avformat/nsvdec: Fix DoS due to lack of eof check in
    nsvs_file_offset loop. [CVE-2017-14171] [boo#1057539]
  * avutil/pixdesc: av_color_primaries_name NULL deref fixed
    [CVE-2017-14225] [boo#1058018]
* Sat Aug 26 2017 jengelh@inai.de
- Unconditionalize celt, ass, openjpeg, webp, libva, vdpau.
* Fri Aug 25 2017 olaf@aepfle.de
- Build unconditionally with lame and twolame
* Mon Jun 19 2017 idonmez@suse.com
- Update to new upstream release 2.8.12
  * Lots of integer overflow fixes, see the included Changelog for
    full details. bsc#1046211
* Tue Apr 18 2017 jengelh@inai.de
- Enable AC3 and MP3 decoding to match multimedia:libs/ffmpeg (3.x)
* Sat Apr  1 2017 jengelh@inai.de
- Update to new upstream release 2.8.11
  * pgssubdec: reset rle_data_len/rle_remaining_len on allocation
  error
  * avformat/oggdec: Skip streams in duration correction that did
  not had their duration set.
  * avcodec/mpeg4videodec: Fix undefined shifts in
  mpeg4_decode_sprite_trajectory()
  * avformat/avidec: skip odml master index chunks in avi_sync
  * avcodec/pngdec: Fix off by 1 size in decode_zbuf()
  * lavf/mov.c: Avoid heap allocation wrap in mov_read_hdlr
  * lavf/mov.c: Avoid heap allocation wrap in mov_read_uuid
  * resolved CVE-2016-9561 [boo#1015120],
  CVE-2017-7863 [boo#1034179], CVE-2017-7865 [boo#1034177],
  CVE-2017-7866 [boo#1034176]
* Sat Apr  1 2017 davejplater@gmail.com
- Update to 2.8.10 to fix boo#1022920 VUL-0: CVE-2016-10190
- Removed patches 0001-avcodec-ansi-Check-dimensions.patch,
  0001-avcodec-cavsdsp-use-av_clip_uint8-for-idct.patch,
  0001-avformat-avidec-Remove-ancient-assert.patch and
  0001-avformat-avidec-Check-nb_streams-in-read_gab2_sub.patch.
  They are incorporated in this version.
- Upstream changes:
  * avformat/http: Match chunksize checks to master..3.0
  * Changelog: fix typos
  * ffserver: Check chunk size
  * Avoid using the term "file" and prefer "url" in some docs
  and comments
  * avformat/rtmppkt: Check for packet size mismatches
  * zmqsend: Initialize ret to 0
  * configure: check for strtoull on msvc
  * http: move chunk handling from http_read_stream() to
  http_buf_read().
  * http: make length/offset-related variables unsigned.
  * avcodec/flacdec: Fix undefined shift in decode_subframe()
  * avcodec/get_bits: Fix get_sbits_long(0)
  * avformat/ffmdec: Check media type for chunks
  * avcodec/flacdec: Fix signed integer overflow in
  decode_subframe_fixed()
  * avcodec/flacdsp_template: Fix undefined shift in
  flac_decorrelate_indep_c
  * avformat/oggparsespeex: Check frames_per_packet and packet_size
  * avformat/utils: Check start/end before computing duration in
  update_stream_timings()
  * avcodec/flac_parser: Update nb_headers_buffered
  * avformat/idroqdec: Check chunk_size for being too large
  * filmstripdec: correctly check image dimensions
  * mss2: only use error correction for matching block counts
  * softfloat: decrease MIN_EXP to cover full float range
  * libopusdec: default to stereo for invalid number of channels
  * sbgdec: prevent NULL pointer access
  * smacker: limit recursion depth of smacker_decode_bigtree
  * mxfdec: fix NULL pointer dereference in mxf_read_packet_old
  * libschroedingerdec: fix leaking of framewithpts
  * libschroedingerdec: don't produce empty frames
  * softfloat: handle -INT_MAX correctly
  * pnmdec: make sure v is capped by maxval
  * smvjpegdec: make sure cur_frame is not negative
  * icodec: correctly check avio_read return value
  * icodec: fix leaking pkt on error
  * dvbsubdec: fix division by zero in compute_default_clut
  * proresdec_lgpl: explicitly check coff[3] against slice_data_size
  * escape124: reject codebook size 0
  * mpegts: prevent division by zero
  * matroskadec: fix NULL pointer dereference in
  webm_dash_manifest_read_header
  * mpegaudio_parser: don't return AVERROR_PATCHWELCOME
  * mxfdec: fix NULL pointer dereference
  * diracdec: check return code of get_buffer_with_edge
  * ppc: pixblockdsp: do unaligned block accesses correctly again
  * mpeg12dec: unref discarded picture from extradata
  * cavsdec: unref frame before referencing again
  * avformat: prevent triggering request_probe assert in ff_read_packet
  * avformat/mpeg: Adjust vid probe threshold to correct mis-detection
  * avcodec/rv40: Test remaining space in loop of get_dimension()
  * avcodec/ituh263dec: Avoid spending a long time in slice sync
  * avcodec/movtextdec: Add error message for tsmb_size check
  * avcodec/movtextdec: Fix tsmb_size check==0 check
  * avcodec/movtextdec: Fix potential integer overflow
  * avcodec/sunrast: Fix input buffer pointer check
  * avcodec/tscc:  Check side data size before use
  * avcodec/rawdec: Check side data size before use
  * avcodec/msvideo1: Check side data size before use
  * avcodec/qpeg:  Check side data size before use
  * avcodec/qtrle:  Check side data size before use
  * avcodec/msrle:  Check side data size before use
  * avcodec/kmvc:  Check side data size before use
  * avcodec/idcinvideo: Check side data size before use
  * avcodec/cinepak: Check side data size before use
  * avcodec/8bps: Check side data size before use
  * avcodec/dvdsubdec: Fix off by 1 error
  * avcodec/dvdsubdec: Fix buf_size check
  * vp9: change order of operations in adapt_prob().
  * avcodec/interplayvideo: Check side data size before use
  * avformat/mxfdec: Check size to avoid integer overflow in
  mxf_read_utf16_string()
  * avcodec/mpegvideo_enc: Clear mmx state in
  ff_mpv_reallocate_putbitbuffer()
  * avcodec/utils: Clear MMX state before returning from
  avcodec_default_execute*()
  * cmdutils: fix typos
  * lavfi: fix typos
  * lavc: fix typos
  * tools: fix grammar error
  * avutil/mips/generic_macros_msa: rename macro variable which
  causes segfault for mips r6
  * videodsp: fix 1-byte overread in top/bottom READ_NUM_BYTES
  iterations.
  * avformat/avidec: Check nb_streams in read_gab2_sub()
  * avformat/avidec: Remove ancient assert
  * lavc/movtextdec.c: Avoid infinite loop on invalid data.
  * avcodec/ansi: Check dimensions
  * avcodec/cavsdsp: use av_clip_uint8() for idct
  * resolved CVE-2016-10190 [boo#1022920],
  CVE-2016-10191 [boo#1022921], CVE-2016-10192 [boo#1022922]
* Sat Feb 11 2017 olaf@aepfle.de
- Make sure each subpkg comes from the same src.rpm
* Fri Oct 28 2016 olaf@aepfle.de
- Enable libfdk_aac if it is available at buildtime
* Sat Oct  8 2016 jengelh@inai.de
- Add 0001-avcodec-ansi-Check-dimensions.patch,
  0001-avcodec-cavsdsp-use-av_clip_uint8-for-idct.patch
  0001-avformat-avidec-Check-nb_streams-in-read_gab2_sub.patch
  0001-avformat-avidec-Remove-ancient-assert.patch [boo#1003806]
* Wed Sep 28 2016 dimstar@opensuse.org
- Have libavcodec56 additionally provide libavcodec56(unrestricted)
  when building unrestricted: allow third party packages to require
  the unrestricted codec. The existing -full provides is not
  suitable as it can be provided by multiple libavcodec* packages,
  whereas we require a specific ABI version.
* Tue Sep 27 2016 jengelh@inai.de
- Update to new maintenance release 2.8.8
  * avformat/oggparsevp8: fix pts calculation on pages ending with an invisible frame
  * avcodec/mjpegdec: Do not try to detect last scan but apply idct after all scans for progressive jpeg
  * avformat/oggparseopus: Check that granule pos is within the supported range
  * avformat/utils: Check bps before using it in a shift in ff_get_pcm_codec_id()
  * ffmpeg: Check that r_frame_rate is set before attempting to use it
  * avformat/utils: Do not compute the bitrate from duration == 0
  * avformat/utils: Check negative bps before shifting in ff_get_pcm_codec_id()
  * avformat/avidec: Detect index with too short entries
  * avformat/oggparseopus: Fix Undefined behavior in oggparseopus.c and libavformat/utils.c
  * avformat/allformats: Making av_register_all() thread-safe.
  * avcodec/vp9_parser: Check the input frame sizes for being consistent
  * avformat/oggdec: Fix integer overflow with invalid pts
  * avcodec/ffv1enc: Fix assertion failure with non zero bits per sample
  * avcodec/diracdec: Check numx/y
  * avformat/avidec: Fix infinite loop in avi_read_nikon()
- Add 0001-avcodec-exr-Check-tile-positions.patch [bnc#998636]
* Fri Aug 12 2016 jengelh@inai.de
- Make a copy of existing ffmpeg 3.x package (specfiles, patches)
  and add the most recent ffmpeg 2.x series tarball.
  This is for VLC…
- Update to new upstream release 2.8.7
  * swscale/x86/output: Fix yuv2planeX_16* with unaligned destination
  * libwebpenc_animencoder: zero initialize the
  WebPAnimEncoderOptions struct
  * avcodec/avpacket: Fix off by 5 error
* Tue May 31 2016 robert.munteanu@gmail.com
- Guard usage of opencore using bcond_with, boo#980542
* Thu Apr 28 2016 aloisio@gmx.com
- Dropped dcadec (libdca was merged upstream)
* Mon Apr 25 2016 jengelh@inai.de
- Add ffmpeg-codec-choice.diff
* Sun Apr 17 2016 olaf@aepfle.de
- Remove ffmpeg-devel subpackage.
  All users have been converted to pkgconfig
  Add Provides/Obsoletes to libavdevice-devel
* Sun Apr 10 2016 jengelh@inai.de
- Add ffmpeg-new-coder-errors.diff
* Wed Apr  6 2016 jengelh@inai.de
- Another try at organizing the codec-enable list.
  Enable video: AYUV, Dirac, MJPEG, rawvideo, Theora, VP8, VP9, WebP,
  zlib
  Enable audio: Celt, GSM, Opus, Speex, Vorbis
  Enable subtitle: ASS/SSA text, SRT text, UTF-8 plaintext
* Tue Feb 16 2016 olaf@aepfle.de
- Update included pkgconfig files to require the exact version
  of ffmpeg pc files, instead of any later version
  ffmpeg-pkgconfig-version.patch
* Mon Feb 15 2016 idonmez@suse.com
- Remove the optional vo-aacenc dependency, upstream removed it.
* Tue Feb  2 2016 aloisio@gmx.com
- Update to version 2.8.6
  * avcodec/jpeg2000dec: More completely check cdef
  * avutil/opt: check for and handle errors in av_opt_set_dict2()
  * avcodec/flacenc: fix calculation of bits required in case
    of custom sample rate
  * avformat: Document urls a bit
  * avformat/libquvi: Set default demuxer and protocol
    limitations
  * avformat/concat: Check protocol prefix
  * doc/demuxers: Document enable_drefs and use_absolute_path
  * avcodec/mjpegdec: Check for end for both bytes in unescaping
  * avcodec/mpegvideo_enc: Check for integer overflow in
    ff_mpv_reallocate_putbitbuffer()
  * avformat/avformat: Replace some references to filenames by
    urls
  * avcodec/wmaenc: Check ff_wma_init() for failure
  * avcodec/mpeg12enc: Move high resolution thread check to
    before initializing threads
  * avformat/img2dec: Use AVOpenCallback
  * avformat/avio: Limit url option parsing to the documented
    cases
  * avformat/img2dec: do not interpret the filename by default
    if a IO context has been opened
  * avcodec/ass_split: Fix null pointer dereference in
    ff_ass_style_get()
  * mov: Add an option to toggle dref opening
  * avcodec/gif: Fix lzw buffer size
  * avcodec/put_bits: Assert buf_ptr in flush_put_bits()
  * avcodec/tiff: Check subsample & rps values more completely
  * swscale/swscale: Add some sanity checks for srcSlice*
    parameters
  * swscale/x86/rgb2rgb_template: Fix planar2x() for short
    width
  * swscale/swscale_unscaled: Fix odd height inputs for
    bayer_to_yv12_wrapper()
  * swscale/swscale_unscaled: Fix odd height inputs for
    bayer_to_rgb24_wrapper()
  * avcodec/aacenc: Check both channels for finiteness
  * asfdec_o: check for too small size in asf_read_unknown
  * asfdec_o: break if EOF is reached after
    asf_read_packet_header
  * asfdec_o: make sure packet_size is non-zero before seeking
  * asfdec_o: prevent overflow causing seekback
  * asfdec_o: check avio_skip in asf_read_simple_index
  * asfdec_o: reject size > INT64_MAX in asf_read_unknown
  * asfdec_o: only set asf_pkt->data_size after sanity checks
  * Merge commit '8375dc1dd101d51baa430f34c0bcadfa37873896'
  * dca: fix misaligned access in avpriv_dca_convert_bitstream
  * brstm: fix missing closing brace
  * brstm: also allocate b->table in read_packet
  * brstm: make sure an ADPC chunk was read for adpcm_thp
  * vorbisdec: reject rangebits 0 with non-0 partitions
  * vorbisdec: reject channel mapping with less than two
    channels
  * ffmdec: reset packet_end in case of failure
  * avformat/ipmovie: put video decoding_map_size into packet
    and use it in decoder
  * avformat/brstm: fix overflow
* Sun Jan 17 2016 idonmez@suse.com
- Update to version 2.8.5
  * Fixes CVE-2016-1897 and CVE-2016-1898 [boo#961937]
* Mon Dec 28 2015 idonmez@suse.com
- Update to version 2.8.4
  * Many bugfixes, see the included Changelog for all the changes.
  * resolving CVE-2015-8661 [boo#960385], CVE-2015-8662 [boo#960384],
  CVE-2015-8663 [boo#960383]
- Drop ffmpeg-remove_some_unused_ctrl_id_mappings.patch, fixed
  upstream.
* Tue Dec 22 2015 olaf@aepfle.de
- Obsolete ffmpeg-tools from packman
* Mon Dec 21 2015 jengelh@inai.de
- Add some provides to make it easier for firefox to recommend
  this package for installation
* Sat Dec 19 2015 joerg.lorenzen@ki.tng.de
- Added patch ffmpeg-remove_some_unused_ctrl_id_mappings.patch to
  successfully build against libvpx >= 1.5 (at least on PMBS).
* Thu Dec 17 2015 olaf@aepfle.de
- Add buildconditionals for libass,libva,vdpau to fix build in SLE_11
* Mon Dec 14 2015 olaf@aepfle.de
- Rename bcond dca to dcadec
- Add more buildconditionals to get closer to removal of BUILD_ORIG
* Wed Dec  9 2015 olaf@aepfle.de
- Remove unused imlib2
* Mon Dec  7 2015 idonmez@suse.com
- Sync with packman changes
  * All packman specific changes are protected with BUILD_ORIG
- Added the following patches
  * ffmpeg-2.4.5-arm6l.patch
  * ffmpeg-libcdio_cdda-pkgconfig.patch
* Sun Nov 29 2015 jengelh@inai.de
- Update to new upstream maintenance release 2.8.3
  * avformat/matroskadec: Check subtitle stream before dereferencing
  * avcodec/jpeg2000dec: Fix potential integer overflow with tile
  dimensions
  * avcodec/jpeg2000dec: Check for duplicate SIZ marker
  * avcodec/jpeg2000: Change coord to 32bit to support larger than
  32k width or height
  * avcodec/jpeg2000dec: Check SIZ dimensions to be within the
  supported range
  * avcodec/jpeg2000: Check comp coords to be within the supported
  size
  * dds: validate compressed source buffer size
  * dds: validate source buffer size before copying
  * softfloat: assert when the argument of av_sqrt_sf is negative
- Fixes CVE-2015-8363 [bnc#957114], CVE-2015-8364 [bnc#957115],
  CVE-2015-8365 [bnc#957116]
* Sat Nov 14 2015 idonmez@suse.com
- Update to new upstream release 2.8.2, containing fixes for the
  following security issues:
  * CVE-2015-8216 boo#955346
  * CVE-2015-8217 boo#955347
  * CVE-2015-8218 boo#955348
  * CVE-2015-8219 boo#955350
- Upstream changes:
  * various fixes in the aac_fixed decoder
  * various fixes in softfloat
  * swresample/resample: increase precision for compensation
  * lavf/mov: add support for sidx fragment indexes
  * avformat/mxfenc: Only store user comment related tags when needed
  * ffmpeg: Don't try and write sdp info if none of the outputs had an rtp format.
  * apng: use correct size for output buffer
  * jvdec: avoid unsigned overflow in comparison
  * avcodec/jpeg2000dec: Clip all tile coordinates
  * avcodec/microdvddec: Check for string end in 'P' case
  * avcodec/dirac_parser: Fix undefined memcpy() use
  * avformat/xmv: Discard remainder of packet on error
  * avformat/xmv: factor return check out of if/else
  * avcodec/mpeg12dec: Do not call show_bits() with invalid bits
  * avcodec/faxcompr: Add missing runs check in decode_uncompressed()
  * libavutil/channel_layout: Check strtol*() for failure
  * avformat/mpegts: Only start probing data streams within probe_packets
  * avcodec/hevc_ps: Check chroma_format_idc
  * avcodec/ffv1dec: Check for 0 quant tables
  * avcodec/mjpegdec: Reinitialize IDCT on BPP changes
  * avcodec/mjpegdec: Check index in ljpeg_decode_yuv_scan() before using it
  * avcodec/h264_slice: Disable slice threads if there are multiple access units in a packet
  * avformat/hls: update cookies on setcookie response
  * opusdec: Don't run vector_fmul_scalar on zero length arrays
  * avcodec/opusdec: Fix extra samples read index
  * avcodec/ffv1: Initialize vlc_state on allocation
  * avcodec/ffv1dec: update progress in case of broken pointer chains
  * avcodec/ffv1dec: Clear slice coordinates if they are invalid or slice header decoding fails for other reasons
  * rtsp: Allow $ as interleaved packet indicator before a complete response header
  * videodsp: don't overread edges in vfix3 emu_edge.
  * avformat/mp3dec: improve junk skipping heuristic
  * concatdec: fix file_start_time calculation regression
  * avcodec: loongson optimize h264dsp idct and loop filter with mmi
  * avcodec/jpeg2000dec: Clear properties in jpeg2000_dec_cleanup() too
  * avformat/hls: add support for EXT-X-MAP
  * avformat/hls: fix segment selection regression on track changes of live streams
  * configure: Require libkvazaar < 0.7.
  * avcodec/vp8: Do not use num_coeff_partitions in thread/buffer setup
- Drop ffmpeg-mov-sidx-fragment.patch, fixed upstream.
* Sat Oct 31 2015 idonmez@suse.com
- Update to new upstream release 2.8.1
  * Minor bugfix release
  * Includes all changes from. Ffmpeg-mt,
    libav master of 2015-08-28, libav 11 as of 2015-08-28
- Add ffmpeg-mov-sidx-fragment.patch to add sidx fragment indexes.
  Needed for new mpv release.
* Wed Sep  9 2015 jengelh@inai.de
- Update to new upstream release 2.8
  * DirectDraw Surface image/texture decoder
  * Many improvements to the JPEG 2000 decoder
  * New video filters: colorkey, SSIM, showvolume, adrawgraph,
  drawgraph, removegrain, erosion, dilation, deflate, inflate,
  reverse, atadenoise, aphasemeter, showfreqs, vectorscope,
  waveform, hstack, vstack, framerate
  * New audio filters: Dynamic Audio Normalizer as dynaudnorm
  filter, areverse, random, deband, sidechaincompress,
  acrossfade
  * allyuv and allrgb video sources
  * Switched default encoders for webm to VP9 and Opus
  * Removed experimental flag from the JPEG 2000 encoder
* Mon Jul 20 2015 jengelh@inai.de
- Update to new upstream release 2.7.2
- webp: fix infinite loop in webp_decode_frame
- huffyuvdec: validate image size
- avcodec/vp8: Check buffer size in vp8_decode_frame_header()
- avcodec/vp8: Fix null pointer dereference in ff_vp8_decode_free()
- avutil/fifo: Fix the case where func() returns less bytes than
  requested in av_fifo_generic_write()
- bytestream2: set the reader to the end when reading more than
  available
- oggparsedirac: check return value of init_get_bits
- vp9/update_prob: prevent out of bounds table read
- avcodec/pngdec: Check values before updating context in
  decode_fctl_chunk()
- avcodec/pngdec: Copy IHDR & plte state from last thread
- avcodec/pngdec: Require a IHDR chunk before fctl
- avcodec/pngdec: Only allow one IHDR chunk
- ffmpeg: Do not use the data/size of a bitstream filter
  after failure
* Thu Jun 25 2015 jengelh@inai.de
- Enable codecs for audio: PCM, Speex, CELT, FLAC, ILBC, Opus
- Enable codecs for image: BMP/PCX/TGA, TIFF, Sun/SGI/X11 raster
  raw Huff-compressed or uncompressed YUV
- Update to new upstream release 2.7.1
  * postproc: fix unaligned access
  * avcodec/flacenc: Fix Invalid Rice order
  * tls_gnutls: fix hang on disconnection
  * avcodec/ffv1enc: fix bps for >8bit yuv when not explicitly set
  * avio: fix potential crashes when combining ffio_ensure_seekback + crc
  * ffmpeg_opt: Check for localtime() failure
  * configure: Disable VSX on unspecified / generic CPUs
* Thu Jun 25 2015 develop7@develop7.info
- Enabled 'bluray' protocol
* Wed Jun 10 2015 jengelh@inai.de
- Update to new upstream release 2.7
  * New encoders: apng (PNG with alpha)
  * New decoders: TDSC (a JPEG/BGR24/zlib format)
  * New audio filters: chorus
  * New video filters: cover_rect, detelecine, fftfilt, find_rect
- Enable codecs: 012v, ansi, apng, bmp, exr, ffv1, ffvhuff
  * unpack DivX-style packed B-frames in MPEG-4 bitstream filter
  * WebM Live Chunk Muxer
  * nvenc level and tier options
- Canopus HQ/HQA decoder
- Automatically rotate videos based on metadata in ffmpeg
- improved Quickdraw compatibility
- VP9 high bit-depth and extended colorspaces decoding support
- WebPAnimEncoder API when available for encoding and muxing WebP
- Direct3D11-accelerated decoding
- Support Secure Transport
- Multipart JPEG demuxer
* Sat May 23 2015 robert.munteanu@gmail.com
- Fix building with BUILD_ORIG
* Sun May 17 2015 jengelh@inai.de
- Update to new upstream release 2.6.3
  * avcodec/libtheoraenc: Check for av_malloc failure
  * ffmpeg_opt: Fix -timestamp parsing
  * avcodec/cavsdec: Use ff_set_dimensions()
  * swr: fix alignment issue caused by 8ch sse functions
  * avcodec/mjpegdec: fix len computation in ff_mjpeg_decode_dqt()
  * avformat/matroskadec: Cleanup error handling for bz2 & zlib
  * avformat/matroskaenc: Check ff_vorbiscomment_length in
  put_flac_codecpriv()
  * avcodec/mpeg12dec: use the correct dimensions for checking SAR
  * xcbgrab: Validate the capture area
  * xcbgrab: Do not assume the non shm image data is always available
  * avfilter/lavfutils: disable frame threads when decoding a single
  image
  * ffmpeg: remove incorrect network deinit
  * OpenCL: Avoid potential buffer overflow in cmdutils_opencl.c
  * libvpxenc: only set noise reduction w/vp8
  * vp9: remove another optimization branch in iadst16 which causes
  overflows.
  * network: Do not leave context locked on error
  * vp9: remove one optimization branch in iadst16 which causes
  overflows.
  * swresample: Allow reinitialization without ever setting channel
  layouts/counts
  * imgutils: initialize palette padding bytes in av_image_alloc
  * id3v2: catch avio_read errors in check_tag
  * avi: Validate sample_size
  * diracdec: avoid overflow of bytes*8 in decode_lowdelay
  * diracdec: prevent overflow in data_unit_size check
  * matroskadec: use uint64_t instead of int for index_scale
  * pngdec: don't use AV_PIX_FMT_MONOBLACK for apng
  * pngdec: return correct error code from decode_frame_common
  * swscale/ppc/swscale_altivec.c: POWER LE support in yuv2planeX_8()
  delete macro GET_VF() it was wrong
  * matroskadec: export cover art correctly
  * mxfenc: don't try to write footer without header
- Enable building avresample for extra API compat
- Remove ffmpeg-pkgconfig-requires.diff: RPM's pkgconfigdeps.sh is
  scanning Requires.private too.
* Mon May 11 2015 dimstar@opensuse.org
- Add baselibs.conf: provide -32bit libraries (used by xine-32bit).
* Mon Apr 13 2015 jengelh@inai.de
- Update to new upstream release 2.6.2
  * avformat/utils: avoid discarded streams in
  av_find_default_stream_index()
  * avutil/cpu: add missing check for mmxext to av_force_cpu_flags
  * avformat/http: replace cookies with updated values instead of
  appending forever
* Thu Mar 19 2015 jengelh@inai.de
- Update to new upstream release 2.6.1
  * Maintenance release with some bugfixes
* Sun Mar  8 2015 jengelh@inai.de
- Update to new upstream release 2.6
  * The VP9 decoder is now usable on x86(-32) and pre-SSSE3 CPUs.
  * 10-bit support in the SPP video filter
  * New video filters: "colorlevels", "tblend", "palettegen",
  "paletteuse". New audio filters: "dcshift".
  * The old libmpcodecs wrapper is finally gone
  * API changes: introduction of device inputs and outputs
* Tue Jan 27 2015 jengelh@inai.de
- Update to new upstream release 2.5.3
  * AVFoundation screen-grabbing support, animated WebP decoding
  support, and Animated PNG support. UDP-Lite support was added.
* Sun Jan  4 2015 jengelh@inai.de
- Initial package (version 2.5.3) for build.opensuse.org
